# GraphicalSVGStatistics


## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**var_schema** | [**EmbeddedModelSchema**](EmbeddedModelSchema.md) |  | [optional] 
**id** | **str** |  | [optional] 

## Example

```python
from openapi_client.models.graphical_svg_statistics import GraphicalSVGStatistics

# TODO update the JSON string below
json = "{}"
# create an instance of GraphicalSVGStatistics from a JSON string
graphical_svg_statistics_instance = GraphicalSVGStatistics.from_json(json)
# print the JSON string representation of the object
print GraphicalSVGStatistics.to_json()

# convert the object into a dict
graphical_svg_statistics_dict = graphical_svg_statistics_instance.to_dict()
# create an instance of GraphicalSVGStatistics from a dict
graphical_svg_statistics_form_dict = graphical_svg_statistics.from_dict(graphical_svg_statistics_dict)
```
[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


